@@ -11,10 +11,12 @@
  * Caveat emptor.
  *
  * Copyright 2000 Doug Becker, mailto:thebeckers@home.com
+ *
+ * Modification 4/18/00 TBB: JPEG_DEBUG rather than just DEBUG,
+ * so VC++ builds don't spew to standard output, causing
+ * major CGI brain damage
  */
 
-#ifdef HAVE_JPEG
-
 #include <stdio.h>
 #include <stdlib.h>
 #include <setjmp.h>
@@ -24,8 +26,11 @@
 #include "jpeglib.h"
 #include "jerror.h"
 #include "gd.h"
+#include "gdhelpers.h"
 
-static const char * const GD_JPEG_VERSION = "1.0";
+#ifdef HAVE_LIBJPEG
+
+static const char * const GD_JPEG_VERSION = "2.0";
 
 typedef struct _jmpbuf_wrapper {
     jmp_buf jmpbuf;
@@ -90,14 +95,14 @@ gdImageJpegCtx(gdImagePtr im, gdIOCtx *outfile, int quality)
     struct jpeg_compress_struct cinfo;
     struct jpeg_error_mgr jerr;
     int i, j, jidx;
-    /* volatile so we can free it on return from longjmp */
+    /* volatile so we can gdFree it on return from longjmp */
     volatile JSAMPROW row = 0;
     JSAMPROW rowptr[1];
     jmpbuf_wrapper jmpbufw;
     JDIMENSION nlines;
     char comment[255];
 
-#ifdef DEBUG
+#ifdef JPEG_DEBUG
     printf("gd-jpeg: gd JPEG version %s\n", GD_JPEG_VERSION);
     printf("gd-jpeg: JPEG library version %d, %d-bit sample values\n",
 	   JPEG_LIB_VERSION, BITS_IN_JSAMPLE);
@@ -107,7 +112,7 @@ gdImageJpegCtx(gdImagePtr im, gdIOCtx *outfile, int quality)
 	    printf("gd-jpeg: gd colormap index %d: (%d, %d, %d)\n", i,
 		   im->red[i], im->green[i], im->blue[i]);
     }
-#endif /* DEBUG */
+#endif /* JPEG_DEBUG */
 
     memset(&cinfo, 0, sizeof(cinfo));
     memset(&jerr, 0, sizeof(jerr));
@@ -117,7 +122,7 @@ gdImageJpegCtx(gdImagePtr im, gdIOCtx *outfile, int quality)
     if (setjmp(jmpbufw.jmpbuf) != 0) {
 	/* we're here courtesy of longjmp */
 	if (row)
-	    free(row);
+	    gdFree(row);
 	return;
     }
 
@@ -135,7 +140,7 @@ gdImageJpegCtx(gdImagePtr im, gdIOCtx *outfile, int quality)
 
     /* If user requests interlace, translate that to progressive JPEG */
     if (gdImageGetInterlaced(im)) {
-#ifdef DEBUG
+#ifdef JPEG_DEBUG
 	printf("gd-jpeg: interlace set, outputting progressive"
 	       " JPEG image\n"); 
 #endif	
@@ -144,11 +149,11 @@ gdImageJpegCtx(gdImagePtr im, gdIOCtx *outfile, int quality)
 
     jpeg_gdIOCtx_dest(&cinfo, outfile);
 
-    row = (JSAMPROW)calloc(1, cinfo.image_width * cinfo.input_components
+    row = (JSAMPROW)gdCalloc(1, cinfo.image_width * cinfo.input_components
 			   * sizeof(JSAMPLE));
     if (row == 0) {
 	fprintf(stderr, "gd-jpeg: error: unable to allocate JPEG row "
-		"structure: calloc returns NULL\n");
+		"structure: gdCalloc returns NULL\n");
 	jpeg_destroy_compress(&cinfo);
 	return;
     }
@@ -197,7 +202,7 @@ gdImageJpegCtx(gdImagePtr im, gdIOCtx *outfile, int quality)
 
     jpeg_finish_compress(&cinfo);
     jpeg_destroy_compress(&cinfo);
-    free(row);
+    gdFree(row);
 }
 
 gdImagePtr gdImageCreateFromJpeg(FILE *inFile)
@@ -223,14 +228,14 @@ gdImageCreateFromJpegCtx(gdIOCtx *infile)
     struct jpeg_decompress_struct cinfo;
     struct jpeg_error_mgr jerr;
     jmpbuf_wrapper jmpbufw;
-    /* volatile so we can free them after longjmp */
+    /* volatile so we can gdFree them after longjmp */
     volatile JSAMPROW row = 0;
     volatile gdImagePtr im = 0;
     JSAMPROW rowptr[1];
     int i, j, retval;
     JDIMENSION nrows;
 
-#ifdef DEBUG
+#ifdef JPEG_DEBUG
     printf("gd-jpeg: gd JPEG version %s\n", GD_JPEG_VERSION);
     printf("gd-jpeg: JPEG library version %d, %d-bit sample values\n",
 	   JPEG_LIB_VERSION, BITS_IN_JSAMPLE);
@@ -244,7 +249,7 @@ gdImageCreateFromJpegCtx(gdIOCtx *infile)
     if (setjmp(jmpbufw.jmpbuf) != 0) {
 	/* we're here courtesy of longjmp */
 	if (row)
-	    free(row);
+	    gdFree(row);
 	if (im)
 	    gdImageDestroy(im);
 	return 0;
@@ -292,7 +297,7 @@ gdImageCreateFromJpegCtx(gdIOCtx *infile)
 	fprintf(stderr, "gd-jpeg: warning: jpeg_start_decompress"
 		" reports suspended data source\n");
 
-#ifdef DEBUG
+#ifdef JPEG_DEBUG
     printf("gd-jpeg: JPEG image information:");
     if (cinfo.saw_JFIF_marker)
 	printf(" JFIF version %d.%.2d",
@@ -338,7 +343,7 @@ gdImageCreateFromJpegCtx(gdIOCtx *infile)
     }
     printf(" colorspace\n");
     fflush(stdout);
-#endif /* DEBUG */
+#endif /* JPEG_DEBUG */
 
     gdImageInterlace(im, cinfo.progressive_mode != 0);
 
@@ -363,16 +368,16 @@ gdImageCreateFromJpegCtx(gdIOCtx *infile)
 #error IJG JPEG library BITS_IN_JSAMPLE value must be 8 or 12
 #endif
 	im->open[i] = 0;
-#ifdef DEBUG
+#ifdef JPEG_DEBUG
 	printf("gd-jpeg: gd colormap index %d set to (%d, %d, %d)\n", i,
 	       im->red[i], im->green[i], im->blue[i]);
 #endif
     }
 
-    row = calloc(cinfo.output_width, sizeof(JSAMPLE));
+    row = gdCalloc(cinfo.output_width, sizeof(JSAMPLE));
     if (row == 0) {
 	fprintf(stderr, "gd-jpeg: error: unable to allocate row for"
-		" JPEG scanline: calloc returns NULL\n");
+		" JPEG scanline: gdCalloc returns NULL\n");
 	goto error;
     }
     rowptr[0] = row;
@@ -395,13 +400,13 @@ gdImageCreateFromJpegCtx(gdIOCtx *infile)
 
 
     jpeg_destroy_decompress(&cinfo);
-    free(row);
+    gdFree(row);
     return im;
 
 error:
     jpeg_destroy_decompress(&cinfo);
     if (row)
-	free(row);
+	gdFree(row);
     if (im)
 	gdImageDestroy(im);
     return 0;
@@ -499,8 +504,8 @@ fill_input_buffer (j_decompress_ptr cinfo)
 {
   my_src_ptr src = (my_src_ptr) cinfo->src;
   size_t nbytes = 0;
-  size_t got;
-  char *s;
+  /* size_t got; */
+  /* char *s; */
   memset(src->buffer, 0, INPUT_BUF_SIZE);
   while (nbytes < INPUT_BUF_SIZE) {
 	  int got = gdGetBuf(src->buffer + nbytes, 
@@ -589,7 +594,10 @@ skip_input_data (j_decompress_ptr cinfo, long num_bytes)
 void
 term_source (j_decompress_ptr cinfo)
 {
+#if 0
+/* never used */
 	my_src_ptr src = (my_src_ptr) cinfo->src;
+#endif
 }
 
 
